@@ -78,10 +78,6 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
         &self.inner
     }
 
-    fn info(&self) -> Arc<AccessorInfo> {
-        self.info.clone()
-    }
-
     async fn create_dir(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
         self.inner.create_dir(path, args).await.map_err(|err| {
             err.with_operation(Operation::CreateDir)
@@ -196,7 +192,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
 
     fn blocking_create_dir(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
         self.inner.blocking_create_dir(path, args).map_err(|err| {
-            err.with_operation(Operation::BlockingCreateDir)
+            err.with_operation(Operation::CreateDir)
                 .with_context("service", self.info.scheme())
                 .with_context("path", path)
         })
@@ -214,7 +210,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
                 )
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingRead)
+                err.with_operation(Operation::Read)
                     .with_context("service", self.info.scheme())
                     .with_context("path", path)
                     .with_context("range", range.to_string())
@@ -231,7 +227,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
                 )
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingWrite)
+                err.with_operation(Operation::Write)
                     .with_context("service", self.info.scheme())
                     .with_context("path", path)
             })
@@ -239,7 +235,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
 
     fn blocking_copy(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy> {
         self.inner.blocking_copy(from, to, args).map_err(|err| {
-            err.with_operation(Operation::BlockingCopy)
+            err.with_operation(Operation::Copy)
                 .with_context("service", self.info.scheme())
                 .with_context("from", from)
                 .with_context("to", to)
@@ -248,7 +244,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
 
     fn blocking_rename(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename> {
         self.inner.blocking_rename(from, to, args).map_err(|err| {
-            err.with_operation(Operation::BlockingRename)
+            err.with_operation(Operation::Rename)
                 .with_context("service", self.info.scheme())
                 .with_context("from", from)
                 .with_context("to", to)
@@ -257,7 +253,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
 
     fn blocking_stat(&self, path: &str, args: OpStat) -> Result<RpStat> {
         self.inner.blocking_stat(path, args).map_err(|err| {
-            err.with_operation(Operation::BlockingStat)
+            err.with_operation(Operation::Stat)
                 .with_context("service", self.info.scheme())
                 .with_context("path", path)
         })
@@ -273,7 +269,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
                 )
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingDelete)
+                err.with_operation(Operation::Delete)
                     .with_context("service", self.info.scheme())
             })
     }
@@ -288,7 +284,7 @@ impl<A: Access> LayeredAccess for ErrorContextAccessor<A> {
                 )
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingList)
+                err.with_operation(Operation::List)
                     .with_context("service", self.info.scheme())
                     .with_context("path", path)
             })
@@ -325,12 +321,11 @@ impl<T: oio::Read> oio::Read for ErrorContextWrapper<T> {
         self.inner
             .read()
             .await
-            .map(|bs| {
+            .inspect(|bs| {
                 self.processed += bs.len() as u64;
-                bs
             })
             .map_err(|err| {
-                err.with_operation(Operation::ReaderRead)
+                err.with_operation(Operation::Read)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("range", self.range.to_string())
@@ -343,12 +338,11 @@ impl<T: oio::BlockingRead> oio::BlockingRead for ErrorContextWrapper<T> {
     fn read(&mut self) -> Result<Buffer> {
         self.inner
             .read()
-            .map(|bs| {
+            .inspect(|bs| {
                 self.processed += bs.len() as u64;
-                bs
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingReaderRead)
+                err.with_operation(Operation::Read)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("range", self.range.to_string())
@@ -367,7 +361,7 @@ impl<T: oio::Write> oio::Write for ErrorContextWrapper<T> {
                 self.processed += size as u64;
             })
             .map_err(|err| {
-                err.with_operation(Operation::WriterWrite)
+                err.with_operation(Operation::Write)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("size", size.to_string())
@@ -375,9 +369,9 @@ impl<T: oio::Write> oio::Write for ErrorContextWrapper<T> {
             })
     }
 
-    async fn close(&mut self) -> Result<()> {
+    async fn close(&mut self) -> Result<Metadata> {
         self.inner.close().await.map_err(|err| {
-            err.with_operation(Operation::WriterClose)
+            err.with_operation(Operation::Write)
                 .with_context("service", self.scheme)
                 .with_context("path", &self.path)
                 .with_context("written", self.processed.to_string())
@@ -386,7 +380,7 @@ impl<T: oio::Write> oio::Write for ErrorContextWrapper<T> {
 
     async fn abort(&mut self) -> Result<()> {
         self.inner.abort().await.map_err(|err| {
-            err.with_operation(Operation::WriterAbort)
+            err.with_operation(Operation::Write)
                 .with_context("service", self.scheme)
                 .with_context("path", &self.path)
                 .with_context("processed", self.processed.to_string())
@@ -403,7 +397,7 @@ impl<T: oio::BlockingWrite> oio::BlockingWrite for ErrorContextWrapper<T> {
                 self.processed += size as u64;
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingWriterWrite)
+                err.with_operation(Operation::Write)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("size", size.to_string())
@@ -411,9 +405,9 @@ impl<T: oio::BlockingWrite> oio::BlockingWrite for ErrorContextWrapper<T> {
             })
     }
 
-    fn close(&mut self) -> Result<()> {
+    fn close(&mut self) -> Result<Metadata> {
         self.inner.close().map_err(|err| {
-            err.with_operation(Operation::BlockingWriterClose)
+            err.with_operation(Operation::Write)
                 .with_context("service", self.scheme)
                 .with_context("path", &self.path)
                 .with_context("written", self.processed.to_string())
@@ -426,12 +420,11 @@ impl<T: oio::List> oio::List for ErrorContextWrapper<T> {
         self.inner
             .next()
             .await
-            .map(|bs| {
+            .inspect(|bs| {
                 self.processed += bs.is_some() as u64;
-                bs
             })
             .map_err(|err| {
-                err.with_operation(Operation::ListerNext)
+                err.with_operation(Operation::List)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("listed", self.processed.to_string())
@@ -443,12 +436,11 @@ impl<T: oio::BlockingList> oio::BlockingList for ErrorContextWrapper<T> {
     fn next(&mut self) -> Result<Option<oio::Entry>> {
         self.inner
             .next()
-            .map(|bs| {
+            .inspect(|bs| {
                 self.processed += bs.is_some() as u64;
-                bs
             })
             .map_err(|err| {
-                err.with_operation(Operation::BlockingListerNext)
+                err.with_operation(Operation::List)
                     .with_context("service", self.scheme)
                     .with_context("path", &self.path)
                     .with_context("listed", self.processed.to_string())
@@ -459,7 +451,7 @@ impl<T: oio::BlockingList> oio::BlockingList for ErrorContextWrapper<T> {
 impl<T: oio::Delete> oio::Delete for ErrorContextWrapper<T> {
     fn delete(&mut self, path: &str, args: OpDelete) -> Result<()> {
         self.inner.delete(path, args).map_err(|err| {
-            err.with_operation(Operation::DeleterDelete)
+            err.with_operation(Operation::Delete)
                 .with_context("service", self.scheme)
                 .with_context("path", path)
                 .with_context("deleted", self.processed.to_string())
@@ -470,12 +462,11 @@ impl<T: oio::Delete> oio::Delete for ErrorContextWrapper<T> {
         self.inner
             .flush()
             .await
-            .map(|n| {
+            .inspect(|&n| {
                 self.processed += n as u64;
-                n
             })
             .map_err(|err| {
-                err.with_operation(Operation::DeleterFlush)
+                err.with_operation(Operation::Delete)
                     .with_context("service", self.scheme)
                     .with_context("deleted", self.processed.to_string())
             })
@@ -485,7 +476,7 @@ impl<T: oio::Delete> oio::Delete for ErrorContextWrapper<T> {
 impl<T: oio::BlockingDelete> oio::BlockingDelete for ErrorContextWrapper<T> {
     fn delete(&mut self, path: &str, args: OpDelete) -> Result<()> {
         self.inner.delete(path, args).map_err(|err| {
-            err.with_operation(Operation::DeleterDelete)
+            err.with_operation(Operation::Delete)
                 .with_context("service", self.scheme)
                 .with_context("path", path)
                 .with_context("deleted", self.processed.to_string())
@@ -495,12 +486,11 @@ impl<T: oio::BlockingDelete> oio::BlockingDelete for ErrorContextWrapper<T> {
     fn flush(&mut self) -> Result<usize> {
         self.inner
             .flush()
-            .map(|n| {
+            .inspect(|&n| {
                 self.processed += n as u64;
-                n
             })
             .map_err(|err| {
-                err.with_operation(Operation::DeleterFlush)
+                err.with_operation(Operation::Delete)
                     .with_context("service", self.scheme)
                     .with_context("deleted", self.processed.to_string())
             })
